# HG changeset patch
# User Goffi <goffi@goffi.org>
# Date 1509487918 -3600
# Node ID cf9b276f4a08d4c26698d56b767624dd48fc88df
# Parent  1e5b2c35964e873af8df32e7a0171c3d8089ae4f
core (disco): do not cache disco items when node is set

diff -r 1e5b2c35964e -r cf9b276f4a08 src/memory/disco.py
--- a/src/memory/disco.py	Tue Oct 31 23:11:13 2017 +0100
+++ b/src/memory/disco.py	Tue Oct 31 23:11:58 2017 +0100
@@ -198,9 +198,12 @@
         @param use_cache(bool): if True, use cached data if available
         @return: a Deferred which fire disco.DiscoItems
         """
+        server_jid = jid.JID(client.jid.host)
         if jid_ is None:
-            jid_ = jid.JID(client.jid.host)
-            # we cache items only for our own server
+            jid_ = server_jid
+
+        if jid_ == server_jid and not node:
+            # we cache items only for our own server and if node is not set
             try:
                 items = self.host.memory.getEntityData(jid_, ["DISCO_ITEMS"], client.profile)["DISCO_ITEMS"]
                 log.debug(u"[%s] disco items are in cache" % jid_.full())